#include <QtCore>
#include <iostream>
#include "datensatz.h"

using namespace std;

void saveData(const QList<Datensatz> &data, const QString &filename) {
   QFile file(filename);
   if (!file.open(QIODevice::WriteOnly)) return;
   QDataStream ds(&file);
   ds.setVersion(QDataStream::Qt_4_0);
   // Magic Number
   ds << (quint32)0xDEADBEEF;
   // Version
   ds << (qint32)1;
   foreach(Datensatz datum, data)
     ds << datum;
   file.close();
}
QList<Datensatz> readData(const QString &filename) {
   QFile file(filename);
   file.open(QIODevice::ReadOnly);
   QDataStream ds(&file);
   ds.setVersion(QDataStream::Qt_4_0);
   // Magic number
   quint32 magic;
   ds >> magic;
   if (magic != 0xDEADBEEF) { 
     qWarning("Wrong magic!\n");
     return QList<Datensatz>();
   }
   // Version
   qint32 version;
   ds >> version;
   if (version != 1) { 
     qWarning("Wrong version!\n");
     return QList<Datensatz>();
   }
   QList<Datensatz> satzliste;
   Datensatz satz;
   while (!ds.atEnd()) {
     ds >> satz;
     satzliste.append(satz);
   }
   file.close();
   return satzliste;
}
int main()
{
   QList<Datensatz> data;
   data.append(Datensatz("Tilda", "Tilli", "Rosenweg", 4, 20095, 
     "Hamburg"));
   data.append(Datensatz("Lara", "Lila", "Lilienweg", 14, 80799, 
     "Mnchen"));
   saveData(data, "datei.db");
   data.clear();
   data = readData("datei.db");
   foreach(Datensatz satz, data)
     cout << qPrintable(satz.nachname()) << endl;

   return 0;
}
